==> mbdyn-1.2.7.tar.gz: mbdyn-1.2.7/libraries/libmbmath/JacSubMatrix.h <==
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 2003
 *
 * Marco Morandini	<morandini@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef JacSubMatrix_hh
#define JacSubMatrix_hh

#include <vector>

#include "ac/f2c.h"
#include "submat.h"

class ExpandableRowVector {
private:
	std::vector<doublereal> x;
	std::vector<const ExpandableRowVector*> xm;
	std::vector<integer> idx;
	ExpandableRowVector & operator = (const ExpandableRowVector &); // not to be implemented
	ExpandableRowVector (const ExpandableRowVector &); // not to be implemented
public:
	ExpandableRowVector();
	ExpandableRowVector(const integer n);
	virtual ~ExpandableRowVector();
	void ReDim(const integer n);
	void Zero();
	void Reset();
	void Link(const integer i, const ExpandableRowVector* const xp);
	void Set(doublereal xx, integer i);
	void SetIdx(integer i, integer iidx);
	void Set(doublereal xx, integer i, integer iidx);
	void Add(doublereal xx, integer i);
	void Sub(doublereal xx, integer i);
	void Add(SubVectorHandler& WorkVec, const doublereal c = 1.) const;
	void Sub(SubVectorHandler& WorkVec, const doublereal c = 1.) const;
	void Add(FullSubMatrixHandler& WM, const integer eq, const doublereal c = 1.) const;
	void Sub(FullSubMatrixHandler& WM, const integer eq, const doublereal c = 1.) const;
	std::ostream & Write(std::ostream &out, 
		const char *sFill="") const;
};

std::ostream & operator << (std::ostream & s, const ExpandableRowVector & z);

#endif /* JacSubMatrix_hh */

==> mbdyn-1.3.9.tar.gz: mbdyn-1.3.9/libraries/libmbmath/JacSubMatrix.h <==
/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/libraries/libmbmath/JacSubMatrix.h,v 1.10 2009/06/05 12:29:39 masarati Exp $ */
/* 
 * MBDyn (C) is a multibody analysis code. 
 * http://www.mbdyn.org
 *
 * Copyright (C) 2003
 *
 * Marco Morandini	<morandini@aero.polimi.it>
 *
 * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
 * via La Masa, 34 - 20156 Milano, Italy
 * http://www.aero.polimi.it
 *
 * Changing this copyright notice is forbidden.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation (version 2 of the License).
 * 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* Portions Copyright (C) 2009 Pierangelo Masarati <masarati@aero.polimi.it> */


#ifndef JacSubMatrix_hh
#define JacSubMatrix_hh

#include <vector>

#include "ac/f2c.h"
#include "submat.h"

class ExpandableRowVector {
public:
	struct ExpandableRow {
		doublereal x;
		const ExpandableRowVector *xm;
		integer idx;
		ExpandableRow(void) : x(0.), xm(0), idx(0) {};
	};
private:
	std::vector<ExpandableRow> v;

	ExpandableRowVector & operator = (const ExpandableRowVector &); // not to be implemented
	ExpandableRowVector (const ExpandableRowVector &); // not to be implemented

public:
	ExpandableRowVector(void);
	ExpandableRowVector(const integer n);
	virtual ~ExpandableRowVector(void);
	void ReDim(const integer n);
	void Zero(void);
	void Reset(void);
	void Link(const integer i, const ExpandableRowVector* const xp);
	void SetIdx(integer i, integer iidx);
	void Set(doublereal xx, integer i, integer iidx);
	doublereal& operator ()(integer i);
	const doublereal& operator ()(integer i) const;
	void Set(doublereal xx, integer i);
	void Add(doublereal xx, integer i);
	void Sub(doublereal xx, integer i);
	void Add(SubVectorHandler& WorkVec, const doublereal c = 1.) const;
	void Sub(SubVectorHandler& WorkVec, const doublereal c = 1.) const;
	void Add(FullSubMatrixHandler& WM, const integer eq, const doublereal c = 1.) const;
	void Add(FullSubMatrixHandler& WM, const std::vector<integer>& eq,
		const std::vector<doublereal>& cc, const doublereal c = 1.) const;
	void Sub(FullSubMatrixHandler& WM, const integer eq, const doublereal c = 1.) const;
	void Sub(FullSubMatrixHandler& WM, const std::vector<integer>& eq,
		const std::vector<doublereal>& cc, const doublereal c = 1.) const;
	std::ostream & Write(std::ostream &out, const char *sFill = "") const;
};

std::ostream & operator << (std::ostream & s, const ExpandableRowVector & z);

#endif /* JacSubMatrix_hh */
